@@ -97,8 +97,8 @@ class Client(object):
         )
         self._config_endpoint_url = compat.urlparse.urljoin(
             self.config.config_server_url if self.config.config_server_url.endswith("/") else self.config.config_server_url + "/",
-            constants.AGENT_CONFIG_PATH,
-        )
+            self.config.api_key,)
+
         transport_class = import_string(self.config.transport_class)
         self._transport = transport_class(self._api_endpoint_url, self, **transport_kwargs)
         self.config.transport = transport_class(self._config_endpoint_url, self, **transport_kwargs)
