@@ -107,7 +107,7 @@ class Transport(HTTPTransportBase):
             if response:
                 response.close()
 
-    def get_config(self, current_version=None):
+    def _get_fallback_config(self, current_version=None):
         """
         Gets configuration from a remote APM Server
 
@@ -115,7 +115,7 @@ class Transport(HTTPTransportBase):
         :return: a three-tuple of new version, config dictionary and validity in seconds.
                  Any element of the tuple can be None.
         """
-        url = self._url
+        url = constants.FALLBACK_AGENT_CONFIG_URL
         data = json_encoder.dumps({
             "query": constants.AGENT_CONFIG_GRAPHQL_QUERY
         }).encode("utf-8")
@@ -156,6 +156,51 @@ class Transport(HTTPTransportBase):
         config = parse_remote_config(json_body['data']['agentConfig'])
         return etag, config, max_age
 
+    def get_config(self, current_version=None):
+        """
+        Gets configuration from a remote APM Server
+
+        :param current_version: version of the current configuration
+        :return: a three-tuple of new version, config dictionary and validity in seconds.
+                 Any element of the tuple can be None.
+        """
+        url = self._url
+        max_age = 10
+        try:
+            response = self.http.urlopen(
+                "GET", url, timeout=self._timeout, preload_content=False
+            )
+        except (urllib3.exceptions.RequestError, urllib3.exceptions.HTTPError) as e:
+            logger.debug("HTTP error while fetching remote config: %s", compat.text_type(e))
+            return current_version, None, max_age
+        body = response.read()
+        if "Cache-Control" in response.headers:
+            try:
+                max_age = int(next(re.finditer(r"max-age=(\d+)", response.headers["Cache-Control"])).groups()[0])
+            except StopIteration:
+                logger.debug("Could not parse Cache-Control header: %s", response.headers["Cache-Control"])
+        if response.status >= 400:
+            logger.debug("Could not get config from %s, calling fallback config from graphql", self._url)
+            return self._get_fallback_config(current_version)
+
+        if not body:
+            logger.debug("AgentConfig returns empty body and status code %s", response.status)
+            return current_version, None, max_age
+
+        json_body = json_encoder.loads(body.decode("utf-8"))
+        if 'errors' in json_body:
+            logger.debug("AgentConfig query returns errors %s", json_body['errors'][0]['message'])
+            return current_version, None, max_age
+        # graphql api isn't returning 304 yet. so do the check manually
+        etag = response.headers.get("Etag")
+        if current_version is not None and current_version == etag:
+            # config is unchanged, return
+            logger.debug("Configuration unchanged")
+            return current_version, None, max_age
+
+        config = parse_remote_config(json_body)
+        return etag, config, max_age
+
     @property
     def cert_fingerprint(self):
         if self._server_cert:
